==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GdkFontMetrics.h <==
// public class gnu.java.awt.peer.gtk.GdkFontMetrics

// class file dependencies
// @dep_class fb27f17d9b4f8d68 gnu_java_awt_peer_gtk_GdkFontMetrics
// @dep_class 21e22bacd79b3842 java_awt_FontMetrics
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_FontMetrics

#include "java/awt/FontMetrics.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GdkFontMetrics_H_
#define _JC_gnu_java_awt_peer_gtk_GdkFontMetrics_H_

// Forward structure declarations
struct _jc_gnu_java_awt_peer_gtk_GdkFontPeer$object;
struct _jc_java_awt_Font$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$sub_refs	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$refs	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$nonrefs	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object;

typedef struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$fields_struct	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$fields_struct;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vmethods	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtable	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtype	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtype;

// Class fields structure
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$fields_struct {
	jint	FONT__5fMETRICS__5fASCENT;
	jint	FONT__5fMETRICS__5fDESCENT;
	jint	FONT__5fMETRICS__5fMAX__5fADVANCE;
	jint	FONT__5fMETRICS__5fMAX__5fASCENT;
	jint	FONT__5fMETRICS__5fMAX__5fDESCENT;
	jint	TEXT__5fMETRICS__5fHEIGHT;
	jint	TEXT__5fMETRICS__5fWIDTH;
	jint	TEXT__5fMETRICS__5fX__5fADVANCE;
	jint	TEXT__5fMETRICS__5fX__5fBEARING;
	jint	TEXT__5fMETRICS__5fY__5fADVANCE;
	jint	TEXT__5fMETRICS__5fY__5fBEARING;
};
extern _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$fields_struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$class_fields;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$_init$b709f73b4bc63e20(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *, struct _jc_java_awt_Font$object *);

// Virtual methods
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$charWidth$3214dae77b6d0f10(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *, jchar);
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$charsWidth$e3fa6584ff0064be(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *, struct _jc_char_array *, jint, jint);
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$getAscent$b8791506474c03f8(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *);
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$getDescent$28036be66c05b672(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *);
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$getLeading$bc31ab9092fba6de(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *);
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$getMaxAdvance$41488da43ffc223b(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *);
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$getMaxAscent$f936fb6e86e8369e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *);
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$getMaxDescent$e8834196160b3b10(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *);
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$stringWidth$58a5781ff5a1fe3a(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$charWidth$3214dae77b6d0f10;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$charsWidth$e3fa6584ff0064be;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$getAscent$b8791506474c03f8;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$getDescent$28036be66c05b672;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$getLeading$bc31ab9092fba6de;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$getMaxAdvance$41488da43ffc223b;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$getMaxAscent$f936fb6e86e8369e;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$getMaxDescent$e8834196160b3b10;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$stringWidth$58a5781ff5a1fe3a;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vmethods {
	jint	(*charWidth$3214dae77b6d0f10)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *, jchar);
	jint	(*charsWidth$e3fa6584ff0064be)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *, struct _jc_char_array *, jint, jint);
	jint	(*getAscent$b8791506474c03f8)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *);
	jint	(*getDescent$28036be66c05b672)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *);
	jint	(*getLeading$bc31ab9092fba6de)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *);
	jint	(*getMaxAdvance$41488da43ffc223b)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *);
	jint	(*getMaxAscent$f936fb6e86e8369e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *);
	jint	(*getMaxDescent$e8834196160b3b10)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *);
	jint	(*stringWidth$58a5781ff5a1fe3a)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_FontMetrics$vmethods	java_awt_FontMetrics;
	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vmethods	gnu_java_awt_peer_gtk_GdkFontMetrics;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$sub_refs {
	_jc_int_array	*font__5fmetrics;
	struct _jc_gnu_java_awt_peer_gtk_GdkFontPeer$object	*peer;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$refs {
    _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$sub_refs	gnu_java_awt_peer_gtk_GdkFontMetrics;
    _jc_java_awt_FontMetrics$sub_refs	java_awt_FontMetrics;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_FontMetrics$sub_nonrefs	java_awt_FontMetrics;
    _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$sub_nonrefs	gnu_java_awt_peer_gtk_GdkFontMetrics;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object {
	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtype _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GdkFontMetrics, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GdkFontMetrics_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/peer/gtk/GdkFontMetrics.h <==
// public class gnu.java.awt.peer.gtk.GdkFontMetrics

// class file dependencies
// @dep_class fb27f17d9b4f8d68 gnu_java_awt_peer_gtk_GdkFontMetrics
// @dep_class f7c692c910b7188c java_awt_FontMetrics
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_FontMetrics

#include "java/awt/FontMetrics.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GdkFontMetrics_H_
#define _JC_gnu_java_awt_peer_gtk_GdkFontMetrics_H_

// Forward structure declarations
struct _jc_gnu_java_awt_peer_gtk_GdkFontPeer$object;
struct _jc_java_awt_Font$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$sub_refs	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$refs	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$nonrefs	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object;

typedef struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$fields_struct	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$fields_struct;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vmethods	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtable	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtype	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtype;

// Class fields structure
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$fields_struct {
	jint	FONT__5fMETRICS__5fASCENT;
	jint	FONT__5fMETRICS__5fDESCENT;
	jint	FONT__5fMETRICS__5fMAX__5fADVANCE;
	jint	FONT__5fMETRICS__5fMAX__5fASCENT;
	jint	FONT__5fMETRICS__5fMAX__5fDESCENT;
	jint	TEXT__5fMETRICS__5fHEIGHT;
	jint	TEXT__5fMETRICS__5fWIDTH;
	jint	TEXT__5fMETRICS__5fX__5fADVANCE;
	jint	TEXT__5fMETRICS__5fX__5fBEARING;
	jint	TEXT__5fMETRICS__5fY__5fADVANCE;
	jint	TEXT__5fMETRICS__5fY__5fBEARING;
};
extern _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$fields_struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$class_fields;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$_init$b709f73b4bc63e20(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *, struct _jc_java_awt_Font$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$charWidth$3214dae77b6d0f10(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *, jchar) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$charsWidth$e3fa6584ff0064be(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$getAscent$b8791506474c03f8(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$getDescent$28036be66c05b672(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$getLeading$bc31ab9092fba6de(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$getMaxAdvance$41488da43ffc223b(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$getMaxAscent$f936fb6e86e8369e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$getMaxDescent$e8834196160b3b10(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method$stringWidth$58a5781ff5a1fe3a(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$charWidth$3214dae77b6d0f10;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$charsWidth$e3fa6584ff0064be;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$getAscent$b8791506474c03f8;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$getDescent$28036be66c05b672;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$getLeading$bc31ab9092fba6de;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$getMaxAdvance$41488da43ffc223b;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$getMaxAscent$f936fb6e86e8369e;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$getMaxDescent$e8834196160b3b10;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$method_info$stringWidth$58a5781ff5a1fe3a;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vmethods {
	jint	(*charWidth$3214dae77b6d0f10)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *, jchar) _JC_JCNI_ATTR;
	jint	(*charsWidth$e3fa6584ff0064be)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
	jint	(*getAscent$b8791506474c03f8)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *) _JC_JCNI_ATTR;
	jint	(*getDescent$28036be66c05b672)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *) _JC_JCNI_ATTR;
	jint	(*getLeading$bc31ab9092fba6de)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *) _JC_JCNI_ATTR;
	jint	(*getMaxAdvance$41488da43ffc223b)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *) _JC_JCNI_ATTR;
	jint	(*getMaxAscent$f936fb6e86e8369e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *) _JC_JCNI_ATTR;
	jint	(*getMaxDescent$e8834196160b3b10)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *) _JC_JCNI_ATTR;
	jint	(*stringWidth$58a5781ff5a1fe3a)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_FontMetrics$vmethods	java_awt_FontMetrics;
	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vmethods	gnu_java_awt_peer_gtk_GdkFontMetrics;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$sub_refs {
	_jc_int_array	*font__5fmetrics;
	struct _jc_gnu_java_awt_peer_gtk_GdkFontPeer$object	*peer;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$refs {
    _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$sub_refs	gnu_java_awt_peer_gtk_GdkFontMetrics;
    _jc_java_awt_FontMetrics$sub_refs	java_awt_FontMetrics;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_FontMetrics$sub_nonrefs	java_awt_FontMetrics;
    _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$sub_nonrefs	gnu_java_awt_peer_gtk_GdkFontMetrics;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$object {
	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GdkFontMetrics$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$vtype _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GdkFontMetrics, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GdkFontMetrics$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GdkFontMetrics_H_ */
